function [agents, time, exposed, latent, exposed_secondary, infected] = advance_in_time(agents, time, ...
    exposed, exposed_secondary, latent, infected, people_data, gqpeople_data, gq_data, params)
            
% Performs a single time step of the simulation. Calls the following function files:
%   progress_from_exposed.m - updates agent status for exposed agents that
%       progress to latent, infected, or back to susceptible
%   endogenous_reactivation.m - updates agent status for latent agents that
%       reactivate
%   recover_from_infected.m - updates agent status for infected agents who
%       recover from active infection and return to latent
%   new_exposures.m - updates agent status for susceptible agents that are 
%       newly exposed in the current timestep.
            
        
    %% Progress from Exposed to Infected, Latent, or back to Susceptible
    if ~isempty(exposed)
        [agents, exposed, latent, infected] = progress_from_exposed(agents, exposed, latent, infected, ...
            people_data, gqpeople_data, gq_data, params);
    end

    %% Progress from Latent to Infected through reactivation
    if ~isempty(latent)
        [agents, latent, infected] = endogenous_reactivation(agents, latent, infected, ...
            people_data, gqpeople_data, gq_data, params);
    end

    %% Recovery from active infection
    if ~isempty(infected)
        [agents, latent, infected] = recover_from_infected(agents, latent, infected);
    end

    %% Determine new exposures
    [agents, exposed, latent, exposed_secondary] = new_exposures(agents, exposed, latent, exposed_secondary, infected);
    
    %% Reinfect
    if ~isempty(exposed_secondary)
        [agents, latent, exposed_secondary, infected] = progress_from_secondary_exposure(agents, latent, ...
            exposed_secondary, infected, people_data, gqpeople_data, gq_data, params);
    end
    
    % update time (in days)
    time = time + params.dt;
        
end