classdef agent
    % Defines the properties of agents (individuals) in the ABM and the
    % interactions between them.
    
    % Possible agent states: S = susceptible
    %                        E = exposed
    %                        L = latent infection
    %                        I = active infection
    %                        Es = secondary exposure
    % Pathways: S can move to E through contact with I
    %           E can move to S (clearance), L, or I (primary infection)
    %           L can move to I (reactivation) or Es
    %           Es can move to L (clearance) or I (reinfection)
    %           I can move to L (recovery)
    
    properties
        age
        status = 'S'
        infectivity = 1
        susceptibility = 1
        progression_from_exposure
        reactivation_rate
        primary_prob
        treatment_rate
        protection_from_reinfection
        householdIndex
        workplaceIndex
        schoolIndex
        gqIndex
        contact_vec
        infected_by = [0 0];
    end
    
    
    
    methods
        
        
        
        function thisAgent = agent(age,status,infectivity,susceptibility,progression_from_exposure,...
                reactivation_rate,primary_prob,treatment_rate,protection_from_reinfection,hh,wp,sch,gq)
            if nargin > 0
                thisAgent.age = age;
                thisAgent.status = status;
                thisAgent.infectivity = infectivity;
                thisAgent.susceptibility = susceptibility;
                thisAgent.progression_from_exposure = progression_from_exposure;
                thisAgent.reactivation_rate = reactivation_rate;
                thisAgent.primary_prob = primary_prob;
                thisAgent.treatment_rate = treatment_rate;
                thisAgent.protection_from_reinfection = protection_from_reinfection;
                thisAgent.householdIndex = hh;
                thisAgent.workplaceIndex = wp;
                thisAgent.schoolIndex = sch;
                thisAgent.gqIndex = gq;
            end
        end
        
        
% The below functions are way too slow if they have to be called for each
% agent, because the people_data structure is huge. 
%
%
%
%         function thisAgent = reactivate(thisAgent, index, people_data, gqpeople_data, params)
%             if rand < thisAgent.reactivation_rate
%                 thisAgent.status = 'I';
%                 if isempty(thisAgent.contact_vec)
%                     thisAgent.contact_vec = determine_contacts(index, people_data, gqpeople_data, params);
%                 end
%             end
%         end
        
        
        
%         function thisAgent = leave_exposed(thisAgent, ind, people_data, gqpeople_data, params)
%             rtemp = rand;
%             prob_to_S = thisAgent.progression_from_exposure*(1-thisAgent.primary_prob)*(1-thisAgent.susceptibility);
%             prob_to_I = thisAgent.progression_from_exposure*thisAgent.primary_prob;
%             prob_to_L = thisAgent.progression_from_exposure*(1-thisAgent.primary_prob)*thisAgent.susceptibility;
% 
%             % Progress to primary infection
%             if rtemp < prob_to_I
%                 thisAgent.status = 'I';
% 
%                 % Determine network contacts
%                 if isempty(thisAgent.contact_vec)
%                     thisAgent.contact_vec = determine_contacts(ind, people_data, gqpeople_data, params);
%                 end
% 
%             % Progress to latent infection
%             elseif rtemp < prob_to_I+prob_to_L
%                 thisAgent.status = 'L';
% 
%             % Clear first infection and return to Susceptible
%             elseif rtemp < prob_to_I+prob_to_L+prob_to_S
%                 thisAgent.status = 'S';
%             end
%         end
        
        
    end
    
end

