function params = define_params_contactweightLHS(LHSmat,i)
    % Define model parameters and run settings
    
    params.savedata = true; % save summary matrices for infected, latent, incidence
    params.savestates = true; % save agent statuses and time to output files at every time step
    % do not include file extensions in file names
    params.savedir = ['gqedit-medTB-contactweight-Washtenaw/',num2str(i)];
    params.savefile = 'data_network'; % filename to save simulation states
    params.seedfile = 'RandomizationRecordKeeping'; % filename to save seed information
    params.infected_init = [];%randi(343322);
    
    params.time_init = 0; % initial time, measured in days
    params.dt = 365/52; % timestep in days
    params.nr_days = 2*365; % number of days to simulate
    params.nr_reps = 10; % number of replicates using the same parameter set
    params.countyfolder = 'synthetic-populations/Washtenaw-county-MI/'; % should be of the form 'CountyName-STATE'
    params.nr_infected = 1; % number of initial infections
    params.fraction_latent = 0.05; % fraction of the total population that is initially latent

    params.latent_init = [];%;randperm(343322, round(343322*params.fraction_latent));
    
    params.weights.hh = LHSmat(i,1); % household contact weights
    params.weights.wp = LHSmat(i,2); % workplace contact weights
    params.weights.sch = LHSmat(i,3); % school contact weights
    params.weights.gq = LHSmat(i,4); % group quarter contact weights
    params.weights.cas = LHSmat(i,5); % contact weights for random/casual contacts
    % For individuals in large schools, workplaces, or group quarters, define
    % the min and max number of contacts they should have 
    params.min_nr_contacts = 10;
    params.max_nr_contacts = 50;

    % casual contacts are contacts made outside the home/workplace/school, e.g.
    % at the gym, church, coffee shop
    params.min_cas_contacts = 50;
    params.max_cas_contacts = 100;

    % susceptibility = probability of infection assuming transmission has occurred
    % should be equal to 1-chi from PDE model
    params.susceptibility = 0.2676;

    % infectivity = probability of transmission per time step to a susceptible host
    % should be equal to beta from PDE model, scaled by dt/365
    params.infectivity = 1-exp(-7.5*params.dt/365);
 
    % progression from Exposed compartment to Latent or Infected
    % should be equal to k from PDE model, scaled by dt/365
    params.progression_from_exposure = 1-exp(-0.277*params.dt/365);

    % probability of primary infection
    % should be equal to p from PDE model
    % min indicates the value for children <10, max indicates the value for
    % adults <20.
    params.min_primary_prob = 0.023;
    params.max_primary_prob = 0.232;

    % rate of recovery from active infection
    % should be equal to d from PDE model, scaled by dt/365
    params.treatment_rate = 1-exp(-2.1*params.dt/365);

    % rate of reactivation of latent infection
    % should be equal to r from PDE model, scaled by dt/365
    params.reactivation_rate = 1-exp(-2.12e-4*params.dt/365);
    
    % protection from reinfection
    % should be equal to sigma from PDE model
    % min indicates the value for children <10, max indicates the value for
    % adults <20.
    params.min_protection_from_reinfection = 0.087;
    params.max_protection_from_reinfection = 0.339;
    
end