function [agents, latent, infected] = endogenous_reactivation(agents, latent, infected, people_data, gqpeople_data, gq_data, params)

% Determines for each agent in the Latent compartment whether they will
% progress to Infected through endogenous reactivation.
%
% Calls determine_contacts.m
%
% Input: agents - vector of agent objects
%        latent and infected - vectors containing the indices of all agents 
%           in the Latent, and Infected compartments, respectively.
%        other inputs are for use in determine_contacts.m:
%           people_data, gqpeople_data - data structures from readdata.m
%           min_nr_contacts, max_nr_contacts - min/max number of contacts 
%               for agents in large schools and workplaces
%           weights - structure with fields hh, wp, sch, and gq containing
%               contact weights corresponding to households, workplaces,
%               schools, and group quarters.
% Output: agents - vector of agents with updated status.
%         latent and infected - updated vectors of indices of agents in the 
%         Latent, and Infected compartments.

    agents_leaving_latent = [];
    for latent_index = 1:length(latent)
        ind = latent(latent_index);
        
        if ~strcmp(agents(ind).status,'L')
            error('Disagreement between agent statuses and latent index vector')
        end

        % Determine if agent will reactivate
        if rand < agents(ind).reactivation_rate
            agents(ind).status = 'I';
            if isempty(agents(ind).contact_vec)
                agents(ind).contact_vec = determine_contacts(ind, people_data, gqpeople_data, gq_data, params);
            end
            infected = [infected ind];
            agents_leaving_latent = [agents_leaving_latent latent_index];
        end
    end
    latent(agents_leaving_latent) = [];

end