function [agents, infected_init, latent_init] = initialize_agents(nr_agents, nr_latent, age_vec, ...
    params, people_data, household_data, workplace_data, school_data, gq_data, gqpeople_data)

% Defines initial attributes and disease states of agents
% Uses agent.m which defines the agent objects.
% Calls determine_contacts.m to calculate network contacts of initially
%   infected agents.

    if isempty(params.infected_init)
        infected_init = randperm(nr_agents, params.nr_infected);
    else
        infected_init = params.infected_init;
    end
    if isempty(params.latent_init)
        latent_init = randperm(nr_agents, nr_latent);
    else
        latent_init = params.latent_init;
    end
    latent_init = setdiff(latent_init,infected_init);

    infectivity = params.infectivity*ones(nr_agents,1);
    susceptibility = params.susceptibility*ones(nr_agents,1);
    progression_from_exposure = params.progression_from_exposure*ones(nr_agents,1);
    primary_prob = params.min_primary_prob + ...
        (params.max_primary_prob-params.min_primary_prob)*min(max(age_vec-10,0),10)/10;
    reactivation_rate = params.reactivation_rate*ones(nr_agents,1);
    treatment_rate = params.treatment_rate*ones(nr_agents,1);
    protection_from_reinfection = params.min_protection_from_reinfection + ...
        (params.max_protection_from_reinfection-params.min_protection_from_reinfection)*min(max(age_vec-10,0),10)/10;
    
    agents(1:nr_agents,1) = agent;
    for i = 1:nr_agents
        
        if ismember(i,infected_init)
            state = 'I';
            % Determine network contacts
            agents(i).contact_vec = determine_contacts(i, people_data, gqpeople_data, gq_data, params);
        elseif ismember(i,latent_init)
            state = 'L';
        else
            state = 'S';
        end
        
        if i <= length(people_data.sp_id) % if included in the people data file (does not include group quarters)
            hh = find(household_data.sp_id == people_data.sp_hh_id(i));
            wp = find(workplace_data.sp_id == people_data.sp_work_id(i));
            sch = find(school_data.sp_id == people_data.sp_school_id(i));
            agents(i) = agent(age_vec(i),state,infectivity(i),susceptibility(i),progression_from_exposure(i),...
                reactivation_rate(i),primary_prob(i),treatment_rate(i),protection_from_reinfection(i),hh,wp,sch,[]);

        else % if included in the group quarters dataset
            gq = find(gq_data.sp_id == gqpeople_data.sp_gq_id(i-length(people_data.sp_id)));
            agents(i) = agent(age_vec(i),state,infectivity(i),susceptibility(i),progression_from_exposure(i),...
                reactivation_rate(i),primary_prob(i),treatment_rate(i),protection_from_reinfection(i),[],[],[],gq);
        end

    end
end