function [agents, exposed, latent, exposed_secondary] = new_exposures(agents, exposed, latent, exposed_secondary, infected)

% Determines what agents are newly exposed in the current time step.
%
% Input: agents - vector of agent objects
%        exposed and infected - vectors containing the indices of all agents 
%           in the Exposed and Infected compartments, respectively.
% Output: agents - vector of agents with updated status.
%         exposed - updated vector of indices of agents in the Exposed
%           compartment.

    infected_index = 1;
    agents_leaving_latent = [];
    while infected_index <= length(infected)

        % determine which agents are exposed to the infected host
        exposed_agents = find(agents(infected(infected_index)).contact_vec>0);

        % determine newly exposed agents
        for k = 1:length(exposed_agents)
            ind = exposed_agents(k);
            probability_of_exposure = agents(infected(infected_index)).infectivity*agents(infected(infected_index)).contact_vec(ind);
            if strcmp(agents(ind).status,'S') && rand < probability_of_exposure
                agents(ind).status = 'E';
                agents(ind).infected_by = [infected(infected_index) agents(infected(infected_index)).contact_vec(ind)];
                exposed = unique([exposed ind]);
            elseif strcmp(agents(ind).status,'L') && rand < probability_of_exposure
                agents(ind).status = 'Es';
                agents(ind).infected_by = [infected(infected_index) agents(infected(infected_index)).contact_vec(ind)];
                agents_leaving_latent = [agents_leaving_latent find(latent==ind)];
                exposed_secondary = unique([exposed_secondary ind]);
            end
        end
        infected_index = infected_index+1;
    end
    latent(agents_leaving_latent) = [];
    
end
