function [people_data,household_data,workplace_data,school_data,gq_data,gqpeople_data] = readdata(folder_name)
    
    % Reads in synthetic population data for use in main_nonspatial.m.
    %
    % This data comes from the 2010 U.S. Synthesized Population Dataset,
    % from RTI International. Contact and citation information is contained
    % in *metadata.csv or .txt in each of the county folders. By default, 
    % the file types are .txt, but the files in Washtenaw-county-MI have
    % been converted to .csv for readability.
    %
    % Data by county can be found at https://www.epimodels.org/drupal-new/?q=node/164
    % Documentation for the data can be found at https://www.epimodels.org//10_Midas_Docs/SynthPop/2010_synth_pop_ver1_quickstart.pdf
    %
    % Input: folder_name is a string containing the path of the folder 
    %   containing the synthetic data..
    % Output: All data output are structures whose fields are the same as
    %   the columns of the data files. A list of all fields is given in the
    %   metadata file, and description of the fields can be found in the 
    %   documentation linked above.
    
    people_file = dir(strcat(folder_name,'*synth_people.*'));
    read_people_data = readtable(strcat(folder_name,people_file.name));
    household_file = dir(strcat(folder_name,'*synth_households.*'));
    read_household_data = readtable(strcat(folder_name,household_file.name));
    workplace_file = dir(strcat(folder_name,'*workplaces.*'));
    read_workplace_data = readtable(strcat(folder_name,workplace_file.name));
    school_file = dir(strcat(folder_name,'*schools.*'));
    read_school_data = readtable(strcat(folder_name,school_file.name));
    gq_file = dir(strcat(folder_name,'*synth_gq.*'));
    read_gq_data = readtable(strcat(folder_name,gq_file.name));
    gqpeople_file = dir(strcat(folder_name,'*synth_gq_people.*'));
    read_gqpeople_data = readtable(strcat(folder_name,gqpeople_file.name));

    
    % convert data tables to structures
    people_data = table2struct(read_people_data,'ToScalar',true);
    household_data = table2struct(read_household_data,'ToScalar',true);
    workplace_data = table2struct(read_workplace_data,'ToScalar',true);
    school_data = table2struct(read_school_data,'ToScalar',true);
    gq_data = table2struct(read_gq_data,'ToScalar',true);
    gqpeople_data = table2struct(read_gqpeople_data,'ToScalar',true);
    
end