function [agents, latent, infected] = recover_from_infected(agents, latent, infected)

% Determines for each agent in the Infected compartment whether they will
% recover from active infection and move to the Latent compartment.
%
% Input: agents - vector of agent objects
%        latent and infected - vectors containing the indices of all agents 
%           in the Latent, and Infected compartments, respectively.
% Output: agents - vector of agents with updated status.
%         latent and infected - updated vectors of indices of agents in the 
%         Latent, and Infected compartments.

    agents_leaving_infected = [];
    
        for infected_index = 1:length(infected)
            ind = infected(infected_index);
            
            if ~strcmp(agents(ind).status,'I')
                error('Disagreement between agent statuses and infected index vector')
            end
            
            % Determine if agent will recover
            if rand < agents(ind).treatment_rate
                agents(ind).status = 'L';
                latent = [latent ind];
                agents_leaving_infected = [agents_leaving_infected infected_index];
            end
        end
        
    infected(agents_leaving_infected) = [];
end